﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using DumpTruck.DrawningObjects;
using DumpTruck.MovementStrategy;

namespace DumpTruck.Generics
{
    internal class CarsGenericStorage
    {
        /// <summary>
        /// Словарь (хранилище)
        /// </summary>
        readonly Dictionary<string, CarsGenericCollection<DrawningCar,
        DrawningObjectCar>> _carStorages;
        /// <summary>
        /// Возвращение списка названий наборов
        /// </summary>
        public List<string> Keys => _carStorages.Keys.ToList();
        /// <summary>
        /// Ширина окна отрисовки
        /// </summary>
        private readonly int _pictureWidth;
        /// <summary>
        /// Высота окна отрисовки
        /// </summary>
        private readonly int _pictureHeight;
        /// <summary>
        /// Конструктор
        /// </summary>
        /// <param name="pictureWidth"></param>
        /// <param name="pictureHeight"></param>
        public CarsGenericStorage(int pictureWidth, int pictureHeight)
        {
            _carStorages = new Dictionary<string,
            CarsGenericCollection<DrawningCar, DrawningObjectCar>>();
            _pictureWidth = pictureWidth;
            _pictureHeight = pictureHeight;
        }
        /// <summary>
        /// Добавление набора
        /// </summary>
        /// <param name="name">Название набора</param>
        public void AddSet(string name)
        {
            // TODO Прописать логику для добавления
            _carStorages.Add(name, new CarsGenericCollection<DrawningCar, DrawningObjectCar>(_pictureWidth, _pictureHeight));
        }
        /// <summary>
        /// Удаление набора
        /// </summary>
        /// <param name="name">Название набора</param>
        public void DelSet(string name)
        {
            if (!_carStorages.ContainsKey(name))
            {
                return;
            }
            _carStorages.Remove(name);
        }
        /// <summary>
        /// Доступ к набору
        /// </summary>
        /// <param name="ind"></param>
        /// <returns></returns>
        public CarsGenericCollection<DrawningCar, DrawningObjectCar>?
        this[string ind]
        {
            get
            {
                if (_carStorages.ContainsKey(ind))
                {
                    return _carStorages[ind];
                }
                return null;
            }
        }
    }

}

