using DumpTruck.DrawningObjects;
using DumpTruck.MovementStrategy;

namespace DumpTruck
{
    public partial class FormDumpTruck : Form
    {
        private DrawningCar? _drawningCar;
        
        private AbstractStrategy? _abstractStrategy;
        private AbstractStrategy? _strategy;

        public DrawningCar? SelectedCar { get; private set; }

        public FormDumpTruck()
        {
            InitializeComponent();
            _strategy = null;
            SelectedCar = null;
        }

        private void button_Click(object sender, EventArgs e)
        {
         
        }

        
        private void Draw()
        {
            if (_drawningCar == null)
            {
                return;
            }
            Bitmap bmp = new Bitmap(pictureBox.Width, pictureBox.Height);
            Graphics gr = Graphics.FromImage(bmp);
            _drawningCar.DrawTransport(gr);
            pictureBox.Image = bmp;
        }

        private void buttonMove_Click(object sender, EventArgs e)
        {
            if (_drawningCar == null)
            {
                return;
            }
            string name = ((Button)sender)?.Name ?? string.Empty;
            switch (name)
            {
                case "buttonUp":
                    _drawningCar.MoveTransport(DirectionType.Up);
                    break;
                case "buttonDown":
                    _drawningCar.MoveTransport(DirectionType.Down);
                    break;
                case "buttonLeft":
                    _drawningCar.MoveTransport(DirectionType.Left);
                    break;
                case "buttonRight":
                    _drawningCar.MoveTransport(DirectionType.Right);
                    break;
            }
            Draw();
        }

        private void button2_Click(object sender, EventArgs e)
        {
            Random random = new();
            Color color = Color.FromArgb(random.Next(0, 256), random.Next(0, 256), random.Next(0, 256));
      
            Color dopColor = Color.FromArgb(random.Next(0, 256), random.Next(0, 256), random.Next(0, 256));
            ColorDialog dialog = new();
            if (dialog.ShowDialog() == DialogResult.OK)
            {
                color = dialog.Color;
            }
            _drawningCar = new DrawningCar(random.Next(100, 300),
            random.Next(1000, 3000),
            color,
            pictureBox.Width, pictureBox.Height);
            _drawningCar.SetPosition(random.Next(10, 100), random.Next(10,
            100));
            Draw();

        }

        private void buttonDumpTruck_Click(object sender, EventArgs e)
        {
            Random random = new();
            Color color = Color.FromArgb(random.Next(0, 256), random.Next(0, 256), random.Next(0, 256));

            Color dopColor = Color.FromArgb(random.Next(0, 256), random.Next(0, 256), random.Next(0, 256));
            ColorDialog dialog = new();
            if (dialog.ShowDialog() == DialogResult.OK)
            {
                color = dialog.Color;
            }
            if (dialog.ShowDialog() == DialogResult.OK)
            {
                dopColor = dialog.Color;
            }

            _drawningCar = new DrawningDumpTruck(random.Next(100, 300),
            random.Next(1000, 3000),
            color,
            dopColor,
            Convert.ToBoolean(random.Next(0, 2)),
            Convert.ToBoolean(random.Next(0, 2)),
            pictureBox.Width, pictureBox.Height);
            _drawningCar.SetPosition(random.Next(10, 100), random.Next(10,
            100));
            Draw();
        }

        private void buttonStep_Click(object sender, EventArgs e)
        {
            if (_drawningCar == null)
            {
                return;
            }
            if (comboBoxStrategy.Enabled)
            {
                _abstractStrategy = comboBoxStrategy.SelectedIndex
                switch
                {
                    0 => new MoveToCenter(),
                    1 => new MoveToBorder(),
                    _ => null,
                };
                if (_abstractStrategy == null)
                {
                    return;
                }
                _abstractStrategy.SetData(new
                DrawningObjectCar(_drawningCar), pictureBox.Width,
                pictureBox.Height);
                comboBoxStrategy.Enabled = false;
            }
            if (_abstractStrategy == null)
            {
                return;
            }
            _abstractStrategy.MakeStep();
            Draw();
            if (_abstractStrategy.GetStatus() == Status.Finish)
            {
                comboBoxStrategy.Enabled = true;
                _abstractStrategy = null;
            }

        }

        private void comboBoxStrategy_SelectedIndexChanged(object sender, EventArgs e)
        {

        }

        private void buttonSelectCar_Click(object sender, EventArgs e)
        {
            SelectedCar = _drawningCar;
            DialogResult = DialogResult.OK;
        }
    }
}
